Learn R Programming

QR.break (version 1.0.1)

dq.test.lvsl_1: Sequential Test for Additional Breaks within a Range of Quantiles

Description

This function performs a sequential test to determine whether the number of breaks in a quantile regression model should be increased from \(L\) to \(L+1\) using multiple quantiles.

Usage

dq.test.lvsl_1(y, x, q.L, q.R, n.size = 1, vec.date)

Value

A numeric value representing the DQ test statistic.

Arguments

y

A numeric vector of dependent variables (\(NT \times 1\)).

x

A numeric matrix of regressors (\(NT \times p\)).

q.L

A numeric value specifying the lower bound of the quantile range.

q.R

A numeric value specifying the upper bound of the quantile range.

n.size

An integer specifying the size of cross-sections (\(N\)).

vec.date

A numeric vector (\(L \times 1\)) of estimated break dates under the null hypothesis.

Details

This procedure tests for the existence of \(L\) breaks against \(L+1\) breaks based on multiple quantiles: \(H_0: L\) breaks vs. \(H_1: L+1\) breaks.

References

Qu, Z. (2008). Testing for Structural Breaks in Regression Quantiles. Journal of Econometrics, 146(1), 170-184.

Examples

Run this code
# Load data
data(gdp)
y = gdp$gdp
x = gdp[,c("lag1", "lag2")]

# Set quantile range (left and right limits)
q.L = 0.2
q.R = 0.8

# Set N parameter
n.size = 1

# Specify break date under H_0
vec.date = 146

# Run the test
result = dq.test.lvsl_1(y, x, q.L, q.R, n.size, vec.date)
print(result)

Run the code above in your browser using DataLab